@@ -1,6 +1,8 @@
+use solana_sdk::pubkey::Pubkey;
+
 use {
     crate::{env, execute_task},
-    anchor_lang::prelude::Pubkey,
+    anchor_client::anchor_lang::prelude::borsh,
     cronos_sdk::account::*,
     std::str::FromStr,
 };
@@ -14,6 +16,8 @@ pub fn execute_pending_tasks(blocktime: i64) {
     {
         let task = Pubkey::from_str(row.get(0)).unwrap();
         let daemon = Pubkey::from_str(row.get(1)).unwrap();
-        execute_task(task, daemon);
+        let ix_bytes: Vec<u8> = row.get(4);
+        let ix = borsh::try_from_slice_with_schema(ix_bytes.as_slice()).unwrap();
+        execute_task(task, daemon, ix);
     }
 }
